@@ -473,6 +473,20 @@ bool ConfigVariable::isSilentError(void)
     return m_iSilentError;
 }
 
+/* User Mode */
+
+int ConfigVariable::m_iUserMode = 0;
+void ConfigVariable::setUserMode(int _iPromptMode)
+{
+    m_iUserMode = _iPromptMode;
+    ConfigVariable::setPromptMode(_iPromptMode);
+}
+
+int ConfigVariable::getUserMode(void)
+{
+    return m_iUserMode;
+}
+
 /* Prompt Mode */
 
 int ConfigVariable::m_iPromptMode = 0;
@@ -1461,15 +1475,15 @@ std::string& ConfigVariable::getMexFunctionName()
 ** \}
 */
 // executed file with exec
-int ConfigVariable::m_iFileID = 0;
-void ConfigVariable::setExecutedFileID(int _iFileID)
+std::wstring ConfigVariable::m_strFile = L"";
+void ConfigVariable::setExecutedFile(const std::wstring& _strFile)
 {
-    m_iFileID = _iFileID;
+    m_strFile = _strFile;
 }
 
-int ConfigVariable::getExecutedFileID()
+const std::wstring& ConfigVariable::getExecutedFile()
 {
-    return m_iFileID;
+    return m_strFile;
 }
 
 /*
