@@ -244,14 +244,6 @@ public class DatatipManagerMode {
             }
         });
 
-        JMenuItem deleteLast = new JMenuItem(Messages.gettext("Delete the last datatip"));
-        deleteLast.addActionListener(new ActionListener() {
-            public void actionPerformed(ActionEvent actionEvent) {
-                deleteLast(new Integer[] {e.getX(), e.getY()});
-            }
-        });
-        deleteLast.setEnabled(hasLast(new Integer[] {e.getX(), e.getY()}));
-
         JMenuItem editDisplayFunction = new JMenuItem(Messages.gettext("Edit curve datatip display function"));
         editDisplayFunction.addActionListener(new ActionListener() {
             public void actionPerformed(ActionEvent actionEvent) {
@@ -279,7 +271,6 @@ public class DatatipManagerMode {
         menu.add(deleteAll);
         menu.add(deleteAllOnCurve);
         menu.add(deleteNearest);
-        menu.add(deleteLast);
         menu.addSeparator();
         menu.add(editDisplayFunction);
         menu.addSeparator();
@@ -387,20 +378,6 @@ public class DatatipManagerMode {
         }
     }
 
-    /**
-     * Delete last datatip
-     * @param pos the mouse position
-     */
-    private void deleteLast(Integer[] pos) {
-        Integer axes = AxesHandler.clickedAxes(getFigure(), pos);
-        if (axes != null) {
-            Integer datatip = getLastTip(axes);
-            if (datatip != null) {
-                DatatipDelete.deleteDatatip(datatip);
-            }
-        }
-    }
-
     /**
      * Delete the nearest datatip
      * @param pos the mouse position
